#!/usr/bin/env python

"""
Common calendar client utilities.

Copyright (C) 2014, 2015 Paul Boddie <paul@boddie.org.uk>

This program is free software; you can redistribute it and/or modify it under
the terms of the GNU General Public License as published by the Free Software
Foundation; either version 3 of the License, or (at your option) any later
version.

This program is distributed in the hope that it will be useful, but WITHOUT
ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS
FOR A PARTICULAR PURPOSE.  See the GNU General Public License for more
details.

You should have received a copy of the GNU General Public License along with
this program.  If not, see <http://www.gnu.org/licenses/>.
"""

from imiptools.data import uri_items

def update_attendees(obj, added, removed):

    """
    Update the attendees in 'obj' with the given 'added' and 'removed'
    attendee lists. A list is returned containing the attendees whose
    attendance should be cancelled.
    """

    to_cancel = []

    if added or removed:
        attendees = uri_items(obj.get_items("ATTENDEE") or [])

        if removed:
            remaining = []

            for attendee, attendee_attr in attendees:
                if attendee in removed:
                    if attendee_attr.get("PARTSTAT") in ("ACCEPTED", "TENTATIVE"):
                        to_cancel.append((attendee, attendee_attr))
                else:
                    remaining.append((attendee, attendee_attr))

            attendees = remaining

        if added:
            for attendee in added:
                attendees.append((attendee, {"PARTSTAT" : "NEEDS-ACTION", "RSVP" : "TRUE"}))

        obj["ATTENDEE"] = attendees

    return to_cancel

# vim: tabstop=4 expandtab shiftwidth=4
